@@ -563,6 +563,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.core
@@ -595,6 +597,9 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
 
         :param stack: the CDK Stack to run assertions on.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.from_stack)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast("Annotations", jsii.sinvoke(cls, "fromStack", [stack]))
 
     @jsii.member(jsii_name="findError")
@@ -608,6 +613,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.find_error)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findError", [construct_path, message]))
 
     @jsii.member(jsii_name="findInfo")
@@ -621,6 +630,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the info. Provide ``'*'`` to match all infos in the template.
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.find_info)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findInfo", [construct_path, message]))
 
     @jsii.member(jsii_name="findWarning")
@@ -634,6 +647,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.find_warning)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(typing.List[aws_cdk.cx_api.SynthesisMessage], jsii.invoke(self, "findWarning", [construct_path, message]))
 
     @jsii.member(jsii_name="hasError")
@@ -643,6 +660,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_error)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasError", [construct_path, message]))
 
     @jsii.member(jsii_name="hasInfo")
@@ -652,6 +673,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the info. Provide ``'*'`` to match all info in the template.
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_info)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasInfo", [construct_path, message]))
 
     @jsii.member(jsii_name="hasNoError")
@@ -661,6 +686,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the error. Provide ``'*'`` to match all errors in the template.
         :param message: the error message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_no_error)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoError", [construct_path, message]))
 
     @jsii.member(jsii_name="hasNoInfo")
@@ -670,6 +699,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the info. Provide ``'*'`` to match all info in the template.
         :param message: the info message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_no_info)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoInfo", [construct_path, message]))
 
     @jsii.member(jsii_name="hasNoWarning")
@@ -679,6 +712,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_no_warning)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasNoWarning", [construct_path, message]))
 
     @jsii.member(jsii_name="hasWarning")
@@ -688,6 +725,10 @@ class Annotations(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Annota
         :param construct_path: the construct path to the warning. Provide ``'*'`` to match all warnings in the template.
         :param message: the warning message as should be expected. This should be a string or Matcher object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Annotations.has_warning)
+            check_type(argname="argument construct_path", value=construct_path, expected_type=type_hints["construct_path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast(None, jsii.invoke(self, "hasWarning", [construct_path, message]))
 
 
@@ -718,6 +759,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.array_equals)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayEquals", [pattern]))
 
     @jsii.member(jsii_name="arrayWith") # type: ignore[misc]
@@ -729,6 +773,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.array_with)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "arrayWith", [pattern]))
 
     @jsii.member(jsii_name="exact") # type: ignore[misc]
@@ -738,6 +785,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.exact)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "exact", [pattern]))
 
     @jsii.member(jsii_name="not") # type: ignore[misc]
@@ -747,6 +797,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to NOT match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.not_)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "not", [pattern]))
 
     @jsii.member(jsii_name="objectEquals") # type: ignore[misc]
@@ -761,6 +814,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.object_equals)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectEquals", [pattern]))
 
     @jsii.member(jsii_name="objectLike") # type: ignore[misc]
@@ -775,6 +831,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.object_like)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "objectLike", [pattern]))
 
     @jsii.member(jsii_name="serializedJson") # type: ignore[misc]
@@ -784,6 +843,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: the pattern to match after parsing the encoded JSON.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.serialized_json)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "serializedJson", [pattern]))
 
     @jsii.member(jsii_name="stringLikeRegexp") # type: ignore[misc]
@@ -793,6 +855,9 @@ class Match(metaclass=jsii.JSIIAbstractClass, jsii_type="@aws-cdk/assertions.Mat
 
         :param pattern: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Match.string_like_regexp)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         return typing.cast("Matcher", jsii.sinvoke(cls, "stringLikeRegexp", [pattern]))
 
 
@@ -831,6 +896,10 @@ class MatchCapture:
                 value=value
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MatchCapture.__init__)
+            check_type(argname="argument capture", value=capture, expected_type=type_hints["capture"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         self._values: typing.Dict[str, typing.Any] = {
             "capture": capture,
             "value": value,
@@ -897,6 +966,11 @@ class MatchFailure:
                 path=["path"]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MatchFailure.__init__)
+            check_type(argname="argument matcher", value=matcher, expected_type=type_hints["matcher"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         self._values: typing.Dict[str, typing.Any] = {
             "matcher": matcher,
             "message": message,
@@ -961,6 +1035,9 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         '''
         :param target: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MatchResult.__init__)
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         jsii.create(self.__class__, self, [target])
 
     @jsii.member(jsii_name="compose")
@@ -970,6 +1047,10 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
         :param id: the id of the parent tree.
         :param inner: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MatchResult.compose)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument inner", value=inner, expected_type=type_hints["inner"])
         return typing.cast("MatchResult", jsii.invoke(self, "compose", [id, inner]))
 
     @jsii.member(jsii_name="finished")
@@ -1005,6 +1086,11 @@ class MatchResult(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.MatchR
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MatchResult.push)
+            check_type(argname="argument matcher", value=matcher, expected_type=type_hints["matcher"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument message", value=message, expected_type=type_hints["message"])
         return typing.cast("MatchResult", jsii.invoke(self, "push", [matcher, path, message]))
 
     @jsii.member(jsii_name="recordCapture")
@@ -1097,6 +1183,9 @@ class Matcher(
 
         :param x: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Matcher.is_matcher)
+            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isMatcher", [x]))
 
     @jsii.member(jsii_name="test") # type: ignore[misc]
@@ -1136,6 +1225,9 @@ class _MatcherProxy(Matcher):
 
         :return: the list of match failures. An empty array denotes a successful match.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Matcher.test)
+            check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
     @builtins.property # type: ignore[misc]
@@ -1179,6 +1271,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
 
         :param template: the CloudFormation template formatted as a nested set of records.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.from_json)
+            check_type(argname="argument template", value=template, expected_type=type_hints["template"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromJSON", [template]))
 
     @jsii.member(jsii_name="fromStack") # type: ignore[misc]
@@ -1188,6 +1283,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
 
         :param stack: the CDK Stack to run assertions on.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.from_stack)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromStack", [stack]))
 
     @jsii.member(jsii_name="fromString") # type: ignore[misc]
@@ -1197,6 +1295,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
 
         :param template: the CloudFormation template in.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.from_string)
+            check_type(argname="argument template", value=template, expected_type=type_hints["template"])
         return typing.cast("Template", jsii.sinvoke(cls, "fromString", [template]))
 
     @jsii.member(jsii_name="findConditions")
@@ -1210,6 +1311,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the condition. Provide ``'*'`` to match all conditions in the template.
         :param props: by default, matches all Conditions in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.find_conditions)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findConditions", [logical_id, props]))
 
     @jsii.member(jsii_name="findMappings")
@@ -1223,6 +1328,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the mapping. Provide ``'*'`` to match all mappings in the template.
         :param props: by default, matches all Mappings in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.find_mappings)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findMappings", [logical_id, props]))
 
     @jsii.member(jsii_name="findOutputs")
@@ -1236,6 +1345,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the output. Provide ``'*'`` to match all outputs in the template.
         :param props: by default, matches all Outputs in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.find_outputs)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findOutputs", [logical_id, props]))
 
     @jsii.member(jsii_name="findParameters")
@@ -1249,6 +1362,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the parameter. Provide ``'*'`` to match all parameters in the template.
         :param props: by default, matches all Parameters in the template. When a literal object is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.find_parameters)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findParameters", [logical_id, props]))
 
     @jsii.member(jsii_name="findResources")
@@ -1262,6 +1379,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param type: the type to match in the CloudFormation template.
         :param props: by default, matches all resources with the given type. When a literal is provided, performs a partial match via ``Match.objectLike()``. Use the ``Match`` APIs to configure a different behaviour.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.find_resources)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Mapping[builtins.str, typing.Any]], jsii.invoke(self, "findResources", [type, props]))
 
     @jsii.member(jsii_name="hasCondition")
@@ -1274,6 +1395,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the mapping. Provide ``'*'`` to match all conditions in the template.
         :param props: the output as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_condition)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasCondition", [logical_id, props]))
 
     @jsii.member(jsii_name="hasMapping")
@@ -1286,6 +1411,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the mapping. Provide ``'*'`` to match all mappings in the template.
         :param props: the output as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_mapping)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasMapping", [logical_id, props]))
 
     @jsii.member(jsii_name="hasOutput")
@@ -1298,6 +1427,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the output. Provide ``'*'`` to match all outputs in the template.
         :param props: the output as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_output)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasOutput", [logical_id, props]))
 
     @jsii.member(jsii_name="hasParameter")
@@ -1310,6 +1443,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param logical_id: the name of the parameter. Provide ``'*'`` to match all parameters in the template.
         :param props: the parameter as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_parameter)
+            check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasParameter", [logical_id, props]))
 
     @jsii.member(jsii_name="hasResource")
@@ -1322,6 +1459,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param type: the resource type; ex: ``AWS::S3::Bucket``
         :param props: the entire defintion of the resource as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_resource)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasResource", [type, props]))
 
     @jsii.member(jsii_name="hasResourceProperties")
@@ -1334,6 +1475,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param type: the resource type; ex: ``AWS::S3::Bucket``
         :param props: the 'Properties' section of the resource as should be expected in the template.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.has_resource_properties)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(None, jsii.invoke(self, "hasResourceProperties", [type, props]))
 
     @jsii.member(jsii_name="resourceCountIs")
@@ -1343,6 +1488,10 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
         :param type: the resource type; ex: ``AWS::S3::Bucket``
         :param count: number of expected instances.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.resource_count_is)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
         return typing.cast(None, jsii.invoke(self, "resourceCountIs", [type, count]))
 
     @jsii.member(jsii_name="templateMatches")
@@ -1351,6 +1500,9 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
 
         :param expected: the expected CloudFormation template as key-value pairs.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Template.template_matches)
+            check_type(argname="argument expected", value=expected, expected_type=type_hints["expected"])
         return typing.cast(None, jsii.invoke(self, "templateMatches", [expected]))
 
     @jsii.member(jsii_name="toJSON")
@@ -1406,6 +1558,9 @@ class Capture(
 
         :param pattern: a nested pattern or Matcher. If a nested pattern is provided ``objectLike()`` matching is applied.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Capture.__init__)
+            check_type(argname="argument pattern", value=pattern, expected_type=type_hints["pattern"])
         jsii.create(self.__class__, self, [pattern])
 
     @jsii.member(jsii_name="asArray")
@@ -1465,6 +1620,9 @@ class Capture(
 
         :param actual: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Capture.test)
+            check_type(argname="argument actual", value=actual, expected_type=type_hints["actual"])
         return typing.cast(MatchResult, jsii.invoke(self, "test", [actual]))
 
     @builtins.property # type: ignore[misc]
